==> refineR_1.5.0.tar.gz: refineR/R/data.R <==

#' Simulated Testcase 1. 
#' 
#' This dataset consists of N = 10,000 simulated measurements with 80\% non-pathological and 20\% pathological samples. 
#' Ground Truth for reference intervals (2.5\% perc., 97.5\% perc): [10.2, 29.8]
#' 
#' @format Numeric vector with data points.  
#' @usage  data(testcase1)
#' 
"testcase1"


#' Simulated Testcase 2. 
#' 
#' This dataset consists of N = 50,000 simulated measurements with 60\% non-pathological and 40\% pathological samples. 
#' Ground Truth for reference intervals (2.5\% perc., 97.5\% perc): [59.8, 160]
#' 
#' @format Numeric vector with data points.  
#' @usage  data(testcase2)
#' 
"testcase2"


#' Simulated Testcase 3. 
#' 
#' This dataset consists of N = 75,000 simulated measurements with 96\% non-pathological and 4\% pathological samples. 
#' Ground Truth for reference intervals (2.5\% perc., 97.5\% perc): [9.04, 13]
#' 
#' @format Numeric vector with data points.  
#' @usage  data(testcase3)
#' 
"testcase3"


#' Simulated Testcase 4. 
#' 
#' This dataset consists of N = 100,000 simulated measurements with 90\% non-pathological and 10\% pathological samples.
#' Ground Truth for reference intervals (2.5\% perc., 97.5\% perc): [10, 50] 
#' 
#' @format Numeric vector with data points.  
#' @usage  data(testcase4)
#' 
"testcase4"


#' Simulated Testcase 5. 
#' 
#' This dataset consists of N = 250,000 simulated measurements with 80\% non-pathological and 20\% pathological samples. 
#' Ground Truth for reference intervals (2.5\% perc., 97.5\% perc): [0.25, 4]
#' 
#' @format Numeric vector with data points.  
#' @usage  data(testcase5)
#' 
"testcase5"

==> refineR_2.0.0.tar.gz: refineR/R/data.R <==

#' Simulated Testcase 1. 
#' 
#' This dataset consists of N = 10,000 simulated measurements with 80\% non-pathological and 20\% pathological samples. 
#' Ground Truth for reference intervals (2.5\% perc., 97.5\% perc): [10.2, 29.8]
#' 
#' @format Numeric vector with data points.  
#' @usage  testcase1
#' 
"testcase1"


#' Simulated Testcase 2. 
#' 
#' This dataset consists of N = 50,000 simulated measurements with 60\% non-pathological and 40\% pathological samples. 
#' Ground Truth for reference intervals (2.5\% perc., 97.5\% perc): [59.8, 160]
#' 
#' @format Numeric vector with data points.  
#' @usage  testcase2
#' 
"testcase2"


#' Simulated Testcase 3. 
#' 
#' This dataset consists of N = 75,000 simulated measurements with 96\% non-pathological and 4\% pathological samples. 
#' Ground Truth for reference intervals (2.5\% perc., 97.5\% perc): [9.04, 13]
#' 
#' @format Numeric vector with data points.  
#' @usage  testcase3
#' 
"testcase3"


#' Simulated Testcase 4. 
#' 
#' This dataset consists of N = 100,000 simulated measurements with 90\% non-pathological and 10\% pathological samples.
#' Ground Truth for reference intervals (2.5\% perc., 97.5\% perc): [10, 50] 
#' 
#' @format Numeric vector with data points.  
#' @usage  testcase4
#' 
"testcase4"


#' Simulated Testcase 5. 
#' 
#' This dataset consists of N = 250,000 simulated measurements with 80\% non-pathological and 20\% pathological samples. 
#' Ground Truth for reference intervals (2.5\% perc., 97.5\% perc): [0.25, 4]
#' 
#' @format Numeric vector with data points.  
#' @usage  testcase5
#' 
"testcase5"
